pub struct ThreadStatus {
pub activity: Option<String>,
pub name: String,
pub short_name: String,
}Expand description
Public view of a point in time status of a thread.
Fields
activity: Option<String>Description of the activity currently in progress by the thread.
NOTE: threads are responsible for reporting their own activity.
name: StringFull name of the thread.
short_name: StringOS name of the thread.
This is called the short name because OS threads names usually have a limit.